Easel (`pyhmmer.easel`)
=======================

.. currentmodule:: pyhmmer.easel


.. automodule:: pyhmmer.easel


Data Structures
---------------

.. autosummary::

   Bitfield
   KeyHash

.. toctree::
   :caption: Data Structures
   :maxdepth: 1
   :hidden:

   Data Structures <data>


Sequences
---------

.. autosummary::

   Sequence
   TextSequence
   DigitalSequence

.. toctree::
   :caption: Sequences
   :maxdepth: 1
   :hidden:

   Sequences <seq>


Sequence Blocks
---------------

.. autosummary::

   SequenceBlock
   TextSequenceBlock
   DigitalSequenceBlock

.. toctree::
   :caption: Sequence Blocks
   :maxdepth: 1
   :hidden:

   Sequence Blocks <block>


Alignments
----------

.. autosummary::

   MSA
   TextMSA
   DigitalMSA

.. toctree::
   :caption: Alignments
   :maxdepth: 1
   :hidden:

   Alignments <msa>


Parsers
-------

.. autosummary::

   SequenceFile
   MSAFile

.. toctree::
   :caption: Parsers
   :maxdepth: 1
   :hidden:

   Parsers <parsers>


Linear Algebra
--------------

.. autosummary::

   Vector
   VectorD
   VectorF
   VectorU8
   Matrix
   MatrixD
   MatrixF
   MatrixU8

.. toctree::
   :caption: Linear Algebra
   :maxdepth: 1
   :hidden:

   Linear Algebra <linalg>


Miscellaneous
-------------

.. autosummary::

   Alphabet
   GeneticCode
   Randomness
   SSIReader
   SSIWriter

.. toctree::
   :caption: Miscellaneous
   :maxdepth: 1
   :hidden:

   Miscellaneous <misc>

